Module: BibTeX
- Defined in:
- lib/relaton/bib/converter/bibtex/to_bibtex.rb
Overview
Monkey patch to fix the issue with month quotes in BibTeX
Defined Under Namespace
Classes: Value
Monkey patch to fix the issue with month quotes in BibTeX
Classes: Value